@@ -24,6 +24,7 @@
 #pragma once
 
 #include <osmocom/core/linuxlist.h>
+#include <osmocom/core/hashtable.h>
 
 struct osmo_pfcp_msg;
 struct osmo_pfcp_endpoint;
@@ -37,6 +38,10 @@ struct up_endpoint {
 
 	/* list of struct up_peer. */
 	struct llist_head peers;
+	/* hashtable of (struct up_session) with key up_seid.
+	 * Allows quick access to sessions (and its endpoint as backpointer)
+	 * with a given up_seid. */
+	DECLARE_HASHTABLE(sessions_by_up_seid, 10);
 
 	uint64_t next_up_seid_state;
 };
